package octez-bls12-381-hash

  1. Overview
  2. Docs

Module type Bls12_381_hash.PERMUTATIONSource

Sourcetype parameters

Parameters for a specific instance

Sourcetype ctxt

Context of the permutation

Sourceval allocate_ctxt : parameters -> ctxt

allocate_ctxt parameters. Allocate a context for a specific instance of the permutation.

Sourceval get_state : ctxt -> Bls12_381.Fr.t array

Return the current state of the context

Sourceval get_state_size : ctxt -> int

Return the state size of the context

Sourceval set_state : ctxt -> Bls12_381.Fr.t array -> unit

set_state ctxt state. Set the context state to the given value. The value state must be of the same size than the expecting state

Sourceval apply_permutation : ctxt -> unit

Apply a permutation on the current state of the context